================================
 Vitrage-Dashboard Release Notes
================================

Contents
========

.. toctree::
   :maxdepth: 2

   unreleased
   2024.1
   2023.2
   2023.1
   zed
   yoga
   xena
   wallaby
   victoria
   ussuri
   train
   stein
   rocky
   queens
   pike
   ocata


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
